from typing import List, Optional

from fastapi.encoders import jsonable_encoder
from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.item import Item
from app.schemas.item import ItemCreate, ItemUpdate


class CRUDItem(CRUDBase[Item, ItemCreate, ItemUpdate]):
    def get_by_sku(self, db: Session, *, sku: str) -> Optional[Item]:
        return db.query(Item).filter(Item.sku == sku).first()
    
    def get_by_supplier(
        self, db: Session, *, supplier_id: int, skip: int = 0, limit: int = 100
    ) -> List[Item]:
        return (
            db.query(Item)
            .filter(Item.supplier_id == supplier_id)
            .offset(skip)
            .limit(limit)
            .all()
        )
    
    def get_by_category(
        self, db: Session, *, category: str, skip: int = 0, limit: int = 100
    ) -> List[Item]:
        return (
            db.query(Item)
            .filter(Item.category == category)
            .offset(skip)
            .limit(limit)
            .all()
        )
    
    def update_quantity(
        self, db: Session, *, item_id: int, quantity_change: int
    ) -> Item:
        item = self.get(db, id=item_id)
        if item:
            item.quantity += quantity_change
            db.add(item)
            db.commit()
            db.refresh(item)
        return item


item = CRUDItem(Item)